pub struct EngineConfig {Show 16 fields
pub download_dir: PathBuf,
pub max_concurrent_downloads: usize,
pub max_connections_per_download: usize,
pub min_segment_size: u64,
pub global_download_limit: Option<u64>,
pub global_upload_limit: Option<u64>,
pub schedule_rules: Vec<ScheduleRule>,
pub user_agent: String,
pub enable_dht: bool,
pub enable_pex: bool,
pub enable_lpd: bool,
pub max_peers: usize,
pub seed_ratio: f64,
pub database_path: Option<PathBuf>,
pub http: HttpConfig,
pub torrent: TorrentConfig,
}Expand description
Main configuration for the download engine
Fields
download_dir: PathBufDirectory to save downloads
max_concurrent_downloads: usizeMaximum concurrent downloads
max_connections_per_download: usizeMaximum connections per download (for segmented HTTP)
min_segment_size: u64Minimum segment size in bytes (won’t split smaller than this)
global_download_limit: Option<u64>Global download speed limit (bytes/sec, None = unlimited)
global_upload_limit: Option<u64>Global upload speed limit (bytes/sec, None = unlimited)
schedule_rules: Vec<ScheduleRule>Bandwidth schedule rules for time-based limits Rules are evaluated in order, first match wins
user_agent: StringDefault user agent
enable_dht: boolEnable DHT for torrents
enable_pex: boolEnable PEX (Peer Exchange) for torrents
enable_lpd: boolEnable LPD (Local Peer Discovery) for torrents
max_peers: usizeMaximum peers per torrent
seed_ratio: f64Stop seeding when this ratio is reached
database_path: Option<PathBuf>Database path for session persistence
http: HttpConfigHTTP configuration
torrent: TorrentConfigBitTorrent configuration
Implementations
Sourceimpl EngineConfig
impl EngineConfig
Sourcepub fn download_dir(self, path: impl Into<PathBuf>) -> Self
pub fn download_dir(self, path: impl Into<PathBuf>) -> Self
Set the download directory
Sourcepub fn max_concurrent_downloads(self, max: usize) -> Self
pub fn max_concurrent_downloads(self, max: usize) -> Self
Set maximum concurrent downloads
Sourcepub fn max_connections_per_download(self, max: usize) -> Self
pub fn max_connections_per_download(self, max: usize) -> Self
Set maximum connections per download
Sourcepub fn download_limit(self, limit: Option<u64>) -> Self
pub fn download_limit(self, limit: Option<u64>) -> Self
Set global download speed limit
Sourcepub fn upload_limit(self, limit: Option<u64>) -> Self
pub fn upload_limit(self, limit: Option<u64>) -> Self
Set global upload speed limit
Sourcepub fn user_agent(self, ua: impl Into<String>) -> Self
pub fn user_agent(self, ua: impl Into<String>) -> Self
Set the user agent
Sourcepub fn schedule_rules(self, rules: Vec<ScheduleRule>) -> Self
pub fn schedule_rules(self, rules: Vec<ScheduleRule>) -> Self
Set bandwidth schedule rules
Sourcepub fn add_schedule_rule(self, rule: ScheduleRule) -> Self
pub fn add_schedule_rule(self, rule: ScheduleRule) -> Self
Add a bandwidth schedule rule
Sourcepub fn database_path(self, path: impl Into<PathBuf>) -> Self
pub fn database_path(self, path: impl Into<PathBuf>) -> Self
Set the database path for persistence
Sourcepub fn get_database_path(&self) -> PathBuf
pub fn get_database_path(&self) -> PathBuf
Get the database path, using default if not set